@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: read_line.c,v 1.3 1999/07/10 13:23:09 bazsi Exp $
+ * $Id: read_line.c,v 1.4 2004/01/13 16:14:01 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -139,8 +139,9 @@ static int do_read_line(struct read_handler **h,
 	      
 	      struct string_read read =
 	      { { STACK_HEADER, do_string_read },
-		closure,
+		NULL,
 		0 };
+	      read.line = closure;
 	      while(next && (read.index < closure->pos))
 		{
 		  res = READ_HANDLER(next, &read.super);
